Fundamental Principles Theory
=============================

It is important to understand the fundamental physical relationships of consigning photonics and electronics systems. Really, we are combining two engineering fields: photonics engineering and electronics engineering. The overlap between the fields, and interconnected relationships, are essential to optimise the system design between them.

.. toctree::
    :caption: Contents:

    fundamentals
    passives
    power_time_metrics

.. include:: fundamentals.rst
.. include:: passives.rst
.. include:: power_time_metrics.rst
